<?php
/**
 * Verificacao sobre o minimo de efetivos: quantidade informada de comensais do cliente (Efetivos do Planejamento) é igual ao somatório de comensais
 * informados por cliente em “Efetivos de Faturamento”
 */
namespace Planejamento\Logic\Efetivos\Exception;

class MinimoEfetivos extends \Planejamento\Logic\Exception
{

    const ERROR = 0;
    const WARNING = 1;


    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $params, $code = 0, \Exception $previous = null)
    {
        parent::__construct($messageName, $code, $previous);
        $this->messageName = $messageName;
        $this->setParams($params);
    }


    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }


    /**
     * Obriga que a somatória de comensais de clientes em Efetivos do Faturamento deve ser igual a quantidade informada de clientes em Efetivos do Planejamento
     * @static
     * @param integer $clientes    Clientes faturados
     * @param integer $servico     Servico dos efetivos
     * @throws MinimoEfetivos
     */
    public static function utilizaConsistenciaSobreMinimoEfetivos($clientes, $servico)
    {
        throw new self ("pla01000_somatorio_clientes_igual", array($clientes, $servico), self::ERROR);
    }


    /**
     * Avisa que a somatória de comensais de clientes em Efetivos do Faturamento difere da quantidade informada de clientes em Efetivos do Planejamento
     * @param $clientes
     * @param $servico
     * @throws MinimoEfetivos
     */
    public static function diferencaComensaisCliente($clientes, $servico)
    {
        throw new self ("pla01000_somatorio_clientes_diferente", array($clientes, $servico), self::WARNING);
    }


}
